'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CLASS_NAME = undefined;
exports.signUp = signUp;
exports.logIn = logIn;
exports.forSession = forSession;
exports.logOut = logOut;

var _copyWithoutFields = require('./copyWithoutFields');

var _copyWithoutFields2 = _interopRequireDefault(_copyWithoutFields);

var _WireFormat = require('./WireFormat');

var _Ops = require('./Ops');

var Ops = _interopRequireWildcard(_Ops);

var _Save = require('./Save');

var _Save2 = _interopRequireDefault(_Save);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var CLASS_NAME = exports.CLASS_NAME = '_User';

function signUp(app, options) {
  var user = {
    username: options.username,
    password: options.password
  };
  if (options.email) {
    user.email = options.email;
  }
  return (0, _Save2.default)(app, '_User', user).then(function (u) {
    if (!u.sessionToken) {
      return Promise.reject('Did not receive an authenticated user from the server.');
    }
    var sanitized = (0, _copyWithoutFields2.default)(u, ['password', 'sessionToken']);
    return Promise.resolve({
      user: sanitized,
      sessionToken: u.sessionToken
    });
  });
}

function logIn(app, options) {
  return app.client.get('login', options, {}).then(function (res) {
    var result = res.response;
    if (!result) {
      return result;
    }
    var u = (0, _WireFormat.decode)(result);
    var sanitized = (0, _copyWithoutFields2.default)(u, ['sessionToken']);
    var serverData = {};
    for (var k in sanitized) {
      serverData[k] = sanitized[k];
    }
    Object.defineProperty(sanitized, '_serverData', {
      enumerable: false,
      writeable: false,
      configurable: false,
      value: serverData
    });
    Object.defineProperty(sanitized, '_className', {
      enumerable: false,
      writeable: false,
      configurable: false,
      value: '_User'
    });
    var token = typeof u.sessionToken === 'string' ? u.sessionToken : '';
    return Promise.resolve({
      user: sanitized,
      sessionToken: token
    });
  });
}

// "become" doesn't make a lot of sense in this sort of library
function forSession(app, token) {
  return app.client.get('users/me', {}, { sessionToken: token }).then(function (res) {
    var result = res.response;
    if (!result) {
      return result;
    }
    var u = (0, _WireFormat.decode)(result);
    return Promise.resolve((0, _copyWithoutFields2.default)(u, ['sessionToken']));
  });
}

function logOut(app, token) {
  return app.client.post('logout', {}, { sessionToken: token }).then(function () {
    return Promise.resolve();
  });
}