'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.encode = encode;
exports.decode = decode;

var _Date = require('./Date');

function encode(data, forcePointer) {
  if (typeof data === 'undefined' || typeof data === 'boolean' || typeof data === 'string' || typeof data === 'number') {
    return data;
  }
  if (data === null) {
    return null;
  }
  if (Array.isArray(data)) {
    return data.map(encode);
  }
  if ((0, _Date.isDate)(data)) {
    var date = {
      __type: 'Date',
      iso: data.toJSON()
    };
    return date;
  }
  if (data.__type) {
    if (data.__type === 'File') {
      var file = {
        __type: 'File',
        name: data.name,
        url: data.url
      };
    }
    if (data.__type === 'GeoPoint') {
      var point = {
        __type: 'GeoPoint',
        latitude: data.latitude,
        longitude: data.longitude
      };
    }
  }
  if (data.hasOwnProperty('latitude') && data.hasOwnProperty('longitude') && Object.keys(data).length === 2) {
    var _point = {
      __type: 'GeoPoint',
      latitude: data.latitude,
      longitude: data.longitude
    };
    return _point;
  }
  if (data.objectId) {
    if (data._className) {
      if (forcePointer) {
        var pointer = {
          __type: 'Pointer',
          objectId: data.objectId,
          className: data._className
        };
        return pointer;
      }
    }
  }
  var encoded = {};
  for (var key in data) {
    encoded[key] = encode(data[key], true);
  }
  return encoded;
} /**
   * Allows objects to be built from or encoded to the wire format used by the
   * Parse-Server to represent complex data types.
   * 
   */

function decode(data) {
  if (typeof data === 'undefined' || typeof data === 'boolean' || typeof data === 'string' || typeof data === 'number') {
    return data;
  }
  if (data === null) {
    return null;
  }
  if (Array.isArray(data)) {
    return data.map(decode);
  }
  if (data.__type === 'Date') {
    return new Date(data.iso);
  }
  var decoded = {};
  if (data.__type) {
    Object.defineProperty(decoded, '__type', {
      enumerable: false,
      writable: false,
      configurable: false,
      value: data.__type
    });
  }
  for (var key in data) {
    if (key === 'createdAt' || key === 'updatedAt') {
      if (typeof data[key] === 'string') {
        var date = new Date(data[key]);
        if (!isNaN(date)) {
          decoded[key] = date;
          continue;
        }
      }
    }
    if (key !== '__type') {
      decoded[key] = decode(data[key]);
    }
  }
  return decoded;
}